@@ -19,8 +19,8 @@ Copyright (c) 2025 Leonard König
 
 __author__ = "Leonard König"
 __license__ = "MIT"
-__version__ = "0.6.0"
-__date__ = "2025-09-12"
+__version__ = "0.7.0"
+__date__ = "2025-09-25"
 __maintainer__ = "Leonard König"
 __email__ = "koenig@tropos.de"
 __title__ = "earthcarekit"
@@ -31,7 +31,7 @@ from .calval import *
 from .download import ecdownload
 from .plot import *
 from .plot import ecquicklook, ecswath
-from .utils import ProfileData, filter_radius, filter_time, geo, read
+from .utils import ProfileData, filter_latitude, filter_radius, filter_time, geo, read
 from .utils import statistics as stats
 from .utils.config import (
     _warn_user_if_not_default_config_exists,
