@@ -49,9 +49,10 @@ from ...utils.time import (
     validate_time_range,
 )
 from ...utils.typing import DistanceRangeLike, ValueRangeLike
-from ..color import Cmap, Color, get_cmap
+from ..color import Cmap, Color, ColorLike, get_cmap
 from ..save import save_plot
 from ._plot_1d_integer_flag import plot_1d_integer_flag
+from ._plot_stacked_propabilities import plot_stacked_propabilities
 from .along_track import AlongTrackAxisStyle, format_along_track_axis
 from .annotation import (
     add_text,
@@ -163,14 +164,15 @@ class LineFigure:
         self.ax.set_xlim((tmin, tmax))  # type: ignore
         self.ax.set_ylim((vmin, vmax))
 
-        self.ax.grid(
-            visible=self.show_grid,
-            which=self.grid_which,
-            axis=self.grid_axis,
-            color=self.grid_color,
-            linestyle=self.grid_linestyle,
-            linewidth=self.grid_linewidth,
-        )
+        if self.show_grid:
+            self.ax.grid(
+                visible=self.show_grid,
+                which=self.grid_which,
+                axis=self.grid_axis,
+                color=self.grid_color,
+                linestyle=self.grid_linestyle,
+                linewidth=self.grid_linewidth,
+            )
 
         self.ax_right.set_ylim(self.ax.get_ylim())
         self.ax_top.set_xlim(self.ax.get_xlim())
@@ -238,8 +240,16 @@ class LineFigure:
         mark_profiles_at: Sequence[TimestampLike] | None = None,
         classes: Sequence[int] | dict[int, str] | None = None,
         classes_kwargs: dict[str, Any] = {},
+        is_prob: bool = False,
+        prob_labels: list[str] | None = None,
+        prob_colors: list[ColorLike] | None = None,
+        zorder: int | float | None = None,
+        label_length: int = 25,
         **kwargs,
     ) -> "LineFigure":
+        _zorder: float = 2.0
+        if isinstance(zorder, (int, float)):
+            _zorder = float(zorder)
         # Parse colors
         color = Color.from_optional(color)
         selection_color = Color.from_optional(selection_color)
@@ -267,14 +277,14 @@ class LineFigure:
             elif log_scale == False and isinstance(norm, LogNorm):
                 norm = Normalize(norm.vmin, norm.vmax)
             if value_range[0] is not None:
-                norm.vmin = value_range[0]
+                norm.vmin = value_range[0]  # type: ignore # FIXME
             if value_range[1] is not None:
-                norm.vmax = value_range[1]
+                norm.vmax = value_range[1]  # type: ignore # FIXME
         else:
             if log_scale == True:
-                norm = LogNorm(value_range[0], value_range[1])
+                norm = LogNorm(value_range[0], value_range[1])  # type: ignore # FIXME
             else:
-                norm = Normalize(value_range[0], value_range[1])
+                norm = Normalize(value_range[0], value_range[1])  # type: ignore # FIXME
         value_range = (norm.vmin, norm.vmax)
 
         values = np.asarray(values)
@@ -285,9 +295,14 @@ class LineFigure:
             longitude = np.asarray(longitude)
 
         # Validate inputs
-        if len(values.shape) != 1:
+        if is_prob:
+            if len(values.shape) != 2:
+                raise ValueError(
+                    f"Since {is_prob=} values must be 2D, but has shape={values.shape}"
+                )
+        elif len(values.shape) != 1:
             raise ValueError(
-                f"Values must be 1D, but has {len(values.shape)} dimensions (shape={values.shape})"
+                f"Since {is_prob=} values must be 1D, but has shape={values.shape}"
             )
 
         tmin_original = time[0]
@@ -357,10 +372,22 @@ class LineFigure:
         x: NDArray = time
         y: NDArray = values
 
-        if classes is not None:
+        if is_prob:
+            plot_stacked_propabilities(
+                ax=self.ax,
+                probabilities=values,
+                time=time,
+                labels=prob_labels,
+                colors=prob_colors,
+                zorder=_zorder,
+                ax_label=label,
+            )
+            vmin = 0
+            vmax = 1
+        elif classes is not None:
             _yaxis_position = classes_kwargs.get("yaxis_position", "left")
             _is_left = _yaxis_position == "left"
-            _label = format_var_label(label, units, label_len=30)
+            _label = format_var_label(label, units, label_len=label_length)
 
             plot_1d_integer_flag(
                 ax=self.ax if _is_left else self.ax_right,
@@ -369,6 +396,7 @@ class LineFigure:
                 x=x,
                 classes=classes,
                 ax_label=_label,
+                zorder=_zorder,
                 **classes_kwargs,
             )
         else:
@@ -382,6 +410,7 @@ class LineFigure:
                     linestyle=linestyle,
                     color=color,
                     alpha=alpha,
+                    zorder=_zorder,
                 )
             elif "scatter" in self.mode:
                 line = self.ax.scatter(
@@ -391,15 +420,16 @@ class LineFigure:
                     s=markersize,
                     color=color,
                     alpha=alpha,
-                )  # , **plot_kwargs)
+                    zorder=_zorder,
+                )
             elif "area" in self.mode:
                 line = self.ax.fill_between(
                     x,
                     [0] * x.shape[0],
                     y,
-                    zorder=0,
                     color=color,
                     alpha=alpha,
+                    zorder=zorder or 0.0,
                 )
             else:
                 raise ValueError(f"invalid `mode` {self.mode}")
@@ -407,14 +437,14 @@ class LineFigure:
             format_numeric_ticks(
                 ax=self.ax,
                 axis="y",
-                label=format_var_label(label, units),
+                label=format_var_label(label, units, label_len=label_length),
                 show_label=self.show_value_left,
                 show_values=self.show_value_left,
             )
             format_numeric_ticks(
                 ax=self.ax_right,
                 axis="y",
-                label=format_var_label(label, units),
+                label=format_var_label(label, units, label_len=label_length),
                 show_label=self.show_value_right,
                 show_values=self.show_value_right,
             )
@@ -518,6 +548,11 @@ class LineFigure:
         mark_profiles_at: Sequence[TimestampLike] | None = None,
         classes: Sequence[int] | dict[int, str] | None = None,
         classes_kwargs: dict[str, Any] = {},
+        is_prob: bool = False,
+        prob_labels: list[str] | None = None,
+        prob_colors: list[ColorLike] | None = None,
+        zorder: int | float | None = None,
+        label_length: int = 25,
         **kwargs,
     ) -> "LineFigure":
         # Collect all common args for wrapped plot function call
