@@ -49,6 +49,8 @@ class SwathFigure:
         title: str | None = None,
         ax_style_top: AlongTrackAxisStyle | str = "geo",
         ax_style_bottom: AlongTrackAxisStyle | str = "time",
+        num_ticks: int = 10,
+        colorbar_tick_scale: float | None = None,
     ):
         self.fig: Figure
         if isinstance(ax, Axes):
@@ -68,6 +70,7 @@ class SwathFigure:
         self.ax_top: Axes | None = None
         self.ax_right: Axes | None = None
         self.colorbar: Colorbar | None = None
+        self.colorbar_tick_scale: float | None = colorbar_tick_scale
         self.selection_time_range: tuple[pd.Timestamp, pd.Timestamp] | None = None
         self.ax_style_top: AlongTrackAxisStyle = AlongTrackAxisStyle.from_input(
             ax_style_top
@@ -78,6 +81,7 @@ class SwathFigure:
 
         self.info_text: AnchoredText | None = None
         self.info_text_loc: str = "upper right"
+        self.num_ticks = num_ticks
 
     def _set_info_text_loc(self, info_text_loc: str | None) -> None:
         if isinstance(info_text_loc, str):
@@ -347,6 +351,7 @@ class SwathFigure:
             tmax_original,
             longitude[:, nadir_index],
             latitude[:, nadir_index],
+            num_ticks=self.num_ticks,
         )
         format_along_track_axis(
             self.ax_top,
@@ -358,6 +363,7 @@ class SwathFigure:
             tmax_original,
             longitude[:, nadir_index],
             latitude[:, nadir_index],
+            num_ticks=self.num_ticks,
         )
 
         return self
@@ -403,7 +409,7 @@ class SwathFigure:
             "from_track_distance", "across_track_distance", "pixel"
         ] = "from_track_distance",
         show_nadir: bool = True,
-        nadir_color: ColorLike | None = "red",
+        nadir_color: ColorLike | None = "black",
         nadir_linewidth: int | float = 1.5,
         label_length: int = 25,
         **kwargs,
@@ -444,7 +450,7 @@ class SwathFigure:
         if value_range is None and log_scale is None and norm is None:
             all_args["norm"] = get_default_norm(var)
         if cmap is None:
-            all_args["cmap"] = get_default_cmap(var)
+            all_args["cmap"] = get_default_cmap(var, file_type=ds)
 
         self.plot(**all_args)
 
@@ -495,6 +501,32 @@ class SwathFigure:
             self.ax_right.invert_yaxis()
         return self
 
+    def set_colorbar_tick_scale(
+        self,
+        multiplier: float | None = None,
+        fontsize: float | str | None = None,
+    ) -> "SwathFigure":
+        _cb = self.colorbar
+        cb: Colorbar
+        if isinstance(_cb, Colorbar):
+            cb = _cb
+        else:
+            return self
+
+        if fontsize is not None:
+            cb.ax.tick_params(labelsize=fontsize)
+            return self
+
+        if multiplier is not None:
+            _fontsize = cb.ax.yaxis.get_ticklabels()[0].get_fontsize()
+            if isinstance(_fontsize, str):
+                from matplotlib import font_manager
+
+                fp = font_manager.FontProperties(size=_fontsize)
+                _fontsize = fp.get_size_in_points()
+            cb.ax.tick_params(labelsize=_fontsize * multiplier)
+        return self
+
     def show(self):
         self.fig.tight_layout()
         self.fig.show()
